import numpy as np
import numpy.typing as npt

def get_color(index: int) -> int: ...
def blit(
    source: npt.NDArray[np.uint32],
    destination: npt.NDArray[np.uint32],
    coordinate: tuple[int, int],
) -> None: ...
def render_tile(
    rom: bytes,
    address: int,
    colors: bytes,
    destination: npt.NDArray[np.uint32],
) -> None: ...



import numpy as np
import numpy.typing as npt

from .run import Apu, Pulse, Noise, Triangle

def apu_mixer(
    apu: Apu,
    pulse1: npt.NDArray[np.uint8],
    pulse2: npt.NDArray[np.uint8],
    triangle: npt.NDArray[np.uint8],
    noise: npt.NDArray[np.uint8],
    dmc: npt.NDArray[np.uint8],
    output: npt.NDArray[np.int16],
) -> None: ...
def generate_pulse(
    pulse: Pulse,
    pulse_out: npt.NDArray[np.uint8],
) -> None: ...
def generate_triangle(
    triangle: Triangle,
    triangle_out: npt.NDArray[np.uint8],
) -> None: ...
def generate_noise(
    noise: Noise,
    noise_out: npt.NDArray[np.uint8],
) -> None: ...



from setuptools import Extension, setup


def get_extensions() -> list[Extension]:
    import numpy

    include_path: str = numpy.get_include()
    nescpu_extension = Extension(
        "famiterm.nescpu",
        include_dirs=[include_path],
        sources=["ext/nescpu.pyx"],
    )
    nesppu_extension = Extension(
        "famiterm.nesppu",
        include_dirs=[include_path],
        sources=["ext/nesppu.pyx"],
    )
    nesapu_extension = Extension(
        "famiterm.nesapu",
        include_dirs=[include_path],
        sources=["ext/nesapu.pyx"],
    )
    return [
        nescpu_extension,
        nesppu_extension,
        nesapu_extension,
    ]


setup(ext_modules=get_extensions())
